@@ -1,6 +1,6 @@
 %%%-------------------------------------------------------------------
 %%% @author Evgeny Khramtsov <ekhramtsov@process-one.net>
-%%% @copyright (C) 2002-2020 ProcessOne, SARL. All Rights Reserved.
+%%% @copyright (C) 2002-2021 ProcessOne, SARL. All Rights Reserved.
 %%%
 %%% Licensed under the Apache License, Version 2.0 (the "License");
 %%% you may not use this file except in compliance with the License.
@@ -34,6 +34,8 @@
 		os_pid :: undefined | pos_integer(),
 		num :: pos_integer()}).
 
+-dialyzer({no_match, [call/2, init/1]}).
+
 %%%===================================================================
 %%% API
 %%%===================================================================
@@ -146,8 +148,7 @@ do_call(Cmd, I, Max, PoolSize, EndTime, CurrTime) ->
 	    Port = get_port((I rem PoolSize) + 1),
 	    monitor_port(Port),
 	    try
-		case port_command(Port, Cmd) of
-		    true ->
+			port_command(Port, Cmd),
 			receive
 			    {Port, Reply} ->
 				demonitor_port(Port),
@@ -157,10 +158,7 @@ do_call(Cmd, I, Max, PoolSize, EndTime, CurrTime) ->
 			after Timeout ->
 				demonitor_port(Port),
 				{error, timeout}
-			end;
-		    false ->
-			erlang:error(badarg)
-		end
+			end
 	    catch _:badarg ->
 		    demonitor_port(Port),
 		    do_call(Cmd, I+1, Max, PoolSize, EndTime,
@@ -221,9 +219,14 @@ demonitor_port(Port) ->
 
 -spec get_bin_path() -> file:filename().
 get_bin_path() ->
-    EbinDir = filename:dirname(code:which(eimp)),
-    AppDir = filename:dirname(EbinDir),
-    filename:join([AppDir, "priv", "bin"]).
+    case code:priv_dir(eimp) of
+	{error, _} ->
+	    EbinDir = filename:dirname(code:which(eimp)),
+	    AppDir = filename:dirname(EbinDir),
+	    filename:join([AppDir, "priv", "bin"]);
+	PrivDir ->
+	    filename:join([PrivDir, "bin"])
+    end.
 
 -spec get_port(pos_integer()) -> undefined | port().
 get_port(I) ->
