@@ -1,6 +1,6 @@
 %%%-------------------------------------------------------------------
 %%% @author Evgeny Khramtsov <ekhramtsov@process-one.net>
-%%% @copyright (C) 2002-2020 ProcessOne, SARL. All Rights Reserved.
+%%% @copyright (C) 2002-2021 ProcessOne, SARL. All Rights Reserved.
 %%%
 %%% Licensed under the Apache License, Version 2.0 (the "License");
 %%% you may not use this file except in compliance with the License.
@@ -21,7 +21,11 @@
 
 test_dir() ->
     {ok, Cwd} = file:get_cwd(),
-    filename:join(filename:dirname(Cwd), "test").
+    CwdClean = case lists:reverse(filename:split(Cwd)) of
+                   [".eunit" | Tail] -> Tail; % when using rebar2
+                   Tail -> Tail % when using rebar3
+    end,
+    filename:join(lists:reverse(["test" | CwdClean])).
 
 start_test() ->
     ?assertMatch({ok, _}, application:ensure_all_started(p1_utils)),
